﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;

namespace Z.Recoding
{
    public partial class Recoding : Form
    {
        string inputText = "C rf;lsv ly`v dc` hfljcnytt ;bnm!"; // Входящие данные (которые нужно перекодировать).
        string outputText = ""; // Выходящие данные (перекодированные).
        int lang = 0; // Хранит информацию о раскладке клавиатуры используемой во входящих даных. (lang > 0 - Английская раскладка, lang < 0 - Русская раскладка).

        char[] eng = new char[] {'~', '@', '#', '$', '%', '^', '&', 'Q', 'W', 'E', 'R', 'T', 'Y', 'U', 'I', 'O', 'P', '{', '}', '|', 
            'A', 'S', 'D', 'F', 'G', 'H', 'J', 'K', 'L', ':', '"', 'Z', 'X', 'C', 'V', 'B', 'N', 'M', '<', '>', '?',
            '`', 'q', 'w', 'e', 'r', 't', 'y', 'u', 'i', 'o', 'p', '[', ']', 'a', 's', 'd', 'f', 'g', 'h', 'j', 'k', 'l', ';', '\'', 
            'z', 'x', 'c', 'v', 'b', 'n', 'm', ',', '.', '/' }; // Английская раскладка клавиатуры (без одинаковых символов с Русской раскладкой).
        char[] rus = new char[] {'Ё', '"', '№', ';', '%', ':', '?', 'Й', 'Ц', 'У', 'К', 'Е', 'Н', 'Г', 'Ш', 'Щ', 'З', 'Х', 'Ъ', '/', 
            'Ф', 'Ы', 'В', 'А', 'П', 'Р', 'О', 'Л', 'Д', 'Ж', 'Э', 'Я', 'Ч', 'С', 'М', 'И', 'Т', 'Ь', 'Б', 'Ю', ',', 
            'ё', 'й', 'ц', 'у', 'к', 'е', 'н', 'г', 'ш', 'щ', 'з', 'х', 'ъ', 'ф', 'ы', 'в', 'а', 'п', 'р', 'о', 'л', 'д', 'ж', 'э', 
            'я', 'ч', 'с', 'м', 'и', 'т', 'ь', 'б', 'ю', '.' }; // Русская раскладка клавиатуры (без одинаковых символов с Английской раскладкой).

        public Recoding()
        {
            InitializeComponent();
            Recode();
        }

        public void Clear()
        {
            inputText = "C rf;lsv ly`v dc` hfljcnytt ;bnm!"; // Входящие данные (которые нужно перекодировать).
            outputText = ""; // Выходящие данные (перекодированные).
            lang = 0; // Хранит информацию о раскладке клавиатуры используемой во входящих даных. (lang > 0 - Английская раскладка, lang < 0 - Русская раскладка).
        }

        public string InfoError(bool clipboard)
        {
            if (clipboard == true)
                return "В буфере обмена не содержится текстовых данных.";
            return "Поле ввода не содержится текстовых данных.";
        }

        public void Recode() // Метод. Перекодирование.
        {
            Clear();
            try
            {
                Clipboard.ContainsText(); // Определяем есть ли в буфере обмена текст.
                inputText = Clipboard.GetText(); // Копируем текст из буфера обмена в исходную переменную.

                for (int i = 0, end = 0; i < inputText.Length & end < 7; i++, end++) // Блок определения раскладки клавиатуры.
                {
                    for (int j = 0; j < eng.Length; j++)
                    {
                        if (inputText[i] == eng[j])
                            lang++;
                        else if (inputText[i] == rus[j])
                            lang--;
                    }
                }

                if (lang > 0) // Z.Recoding (Английская -> Русская).
                {
                    for (int i = 0; i < inputText.Length; i++)
                    {
                        for (int j = 0; j < eng.Length; j++)
                            if (inputText[i] == eng[j])
                                outputText += rus[j];
                        if (outputText.Length <= i)
                            outputText += inputText[i];
                    }
                }
                else  // Z.Recoding (Русская -> Английская).
                {
                    for (int i = 0; i < inputText.Length; i++)
                    {
                        for (int j = 0; j < rus.Length; j++)
                            if (inputText[i] == rus[j])
                                outputText += eng[j];
                        if (outputText.Length <= i)
                            outputText += inputText[i];
                    }
                }
                Clipboard.SetText(outputText);
                textBoxOutput.Text = outputText;
            }
            catch
            {
                textBoxOutput.Text = "В буфере обмена не содержится текстовых данных.";
            }
        }

        // Кнопки и Ссылки.
        private void btnHelp_Click(object sender, EventArgs e)
        {
            MessageBox.Show(@"1. При запуске программы текст, содержащийся в буфере обмена, автоматически перекодируется и сразу помещается в буфер обмена.
Его можно вставить в той программе, в которой это необходимо. Никаких дополнительных действий кроме запуска программы, осуществлять не надо.

2. При запущенной программе, вы можете воспользоваться одной из кнопок.
    а. Перекодирует текст, содержащийся в буфере обмена, и помещает его в буфер обмена и поле ввода окна программы.
    б. Перекодирует текст, содержащийся в поле ввода окна программы, и помещает его в буфер обмена и поле ввода окна программы.


Z.Recoding - Программа с открытым исходным кодом.
Распространяется под лицензией: CC BY-NC-SA 3.0
(Creative Commons Attribution-NonCommercial-ShareAlike 3.0)
Разрешено свободное использование произведения, при условии указания его автора(ов) и только в некоммерческих целях. Также все производные произведения, должны распространяться под лицензией CC BY-NC-SA 3.0");
        }

        private void btnRecodeClipboard_Click(object sender, EventArgs e)
        {
            Recode();
        }

        private void btnRecodeTextBox_Click(object sender, EventArgs e)
        {
            try 
            {
                Clipboard.SetText(textBoxOutput.Text);
                Recode();
            }
            catch 
            {
                textBoxOutput.Text = "Поле ввода не содержит текстовых данных.";
            }
        }

        private void linkHome_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            Process.Start("http://mosc.bursa.ru");
        }

        private void linkLicense_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            Process.Start("http://creativecommons.org/licenses/by-nc-sa/3.0/deed.ru");
        }
    }
}
